@@ -9,7 +9,7 @@ class PKG:
         self.parser.add_argument('--version', action='version', version=__version__)
 
         subparsers = self.parser.add_subparsers(dest='command')
-        InitCommand(subparsers.add_parser('init', help='Create "package.py" file'))
+        InitCommand(subparsers.add_parser('init', help='Create "package.json" file'))
         PublishCommand(subparsers.add_parser('publish', help='Publish package to PyPi'))
 
     def execute(self) -> None:
